<?php
/**
* Customizer Setup and Custom Controls
*
* Adds the individual sections, settings, and controls to the theme customizer
*/
class Empowerment_Initialise_Customizer_Settings {
 	// Get our default values
	private $defaults;
	public function __construct() {
 		// Get our Customizer defaults
		$this->defaults = empowerment_generate_defaults();
 		// Register customizer Panel
		add_action( 'customize_register', array( $this, 'empowerment_customizer_panels' ) );
 		// Register customizer sections
		add_action( 'customize_register', array( $this, 'empowerment_customizer_sections' ) );
 		// Register Header Option Controls
		add_action( 'customize_register', array( $this, 'empowerment_register_header_controls' ) );
 	 	// Register Typography Controls
		add_action( 'customize_register', array( $this, 'empowerment_register_typography_controls' ) );
    	//Register Bread Banner Controls
		add_action( 'customize_register', array($this,'empowerment_register_bread_banner_controls') );
    	//Register Page Option Controls
		add_action( 'customize_register', array($this,'empowerment_register_page_settings_controls') );
    	//Register Archive Option Controls
		add_action( 'customize_register', array($this,'empowerment_register_archive_settings_controls') );
 		// Register Footer Controls
		add_action( 'customize_register', array( $this, 'empowerment_register_footer_settings_controls' ) );
 		// Register Theme Color Controls
		add_action( 'customize_register', array( $this, 'empowerment_register_theme_color_controls' ) );
		add_action( 'customize_register', array( $this, 'empowerment_developer_controls' ) );
		add_action( 'customize_register', array( $this, 'empowerment_seo_controls' ) );
 		// Empowerment Theme active callback
		add_action( 'customize_register', array( $this, 'empowerment_registre_theme_active_callback' ) );
 		// Register woocommerce controls
		if (class_exists('woocommerce')) {
			add_action( 'customize_register', array( $this, 'empowerment_woocommerce_controls' ) );
		}
	}
   	/**
 	 * Register the Customizer panels
 	 */
   	public function empowerment_customizer_panels( $wp_customize ) {
 		/**
 		 * Add Empowerment Theme Options Panel
 		 */
 		$wp_customize->add_panel( 'empowerment_general_settings_panel',
 			array(
 				'title' => esc_html__( 'General', 'empowerment' ),
 				'priority' =>1,
 			)
 		);
	    /**
	     * Header settings
	     */
	    $wp_customize->add_panel( 'empowerment_header_panel',
	    	array(
	    		'title' => esc_html__( 'Header Settings', 'empowerment' ),
	    		'priority' =>2,
	    	)
	    );
 		/**
 		 * Typography setting
 		 */
 		$wp_customize->add_panel( 'empowerment_typography_panel',
 			array(
 				'title' => esc_html__( 'Typography', 'empowerment' ),
 				'priority' =>3,
 			)
 		);
	    /**
	     * Breadcrumb Banner setting
	     */
	    $wp_customize->add_panel( 'empowerment_breadcrumb_panel',
	    	array(
	    		'title' => esc_html__( 'Breadcrumb Banner', 'empowerment' ),
	    		'priority' =>4,
	    	)
	    );
	    /**
	     * Page Settings
	     */
	    $wp_customize->add_panel( 'empowerment_page_panel',
	    	array(
	    		'title' => esc_html__( 'Page Settings', 'empowerment' ),
	    		'priority' =>5,
	    	)
	    );
	    /**
	     * Archive Settings
	     */
	    $wp_customize->add_panel( 'empowerment_archive_panel',
	    	array(
	    		'title' => esc_html__( 'Blog Settings', 'empowerment' ),
	    		'priority' =>6,
	    	)
	    );
	    /**
	     * Shop Settings
	     */
	    $wp_customize->add_panel( 'empowerment_shop_panel',
	    	array(
	    		'title' => esc_html__( 'Shop Settings', 'empowerment' ),
	    		'priority' =>7,
	    	)
	    );
 		/**
 		 * Footer Settings
 		 */
 		$wp_customize->add_panel( 'empowerment_footer_panel',
 			array(
 				'title' => esc_html__( 'Footer Settings', 'empowerment' ),
 				'priority' =>8,
 			)
 		);
 	}
   	/**
 	 * Register the Customizer sections
 	 */
   	public function empowerment_customizer_sections( $wp_customize ) {
		$wp_customize->add_section( new Empowerment_Upsell_Section( $wp_customize, 'empowerment_upsell_section',
			array(
				'title' => __( 'Get Empowerment Pro!', 'empowerment' ),
				'url' => 'https://uncodethemes.com/wordpress-themes/empowerment-pro/#empowerment-pricing',
				'backgroundcolor' => '#EC8F6A',
				'textcolor' => '#fff',
				'priority' => 0,
			)
		) );
		$wp_customize->add_section( new Empowerment_Upsell_Section( $wp_customize, 'empowerment_doc_section',
			array(
				'title' => __( 'View Documentation', 'empowerment' ),
				'url' => 'https://docs.uncodethemes.com/docs-category/empowerment-free-theme/',
				'backgroundcolor' => '#344860',
				'textcolor' => '#fff',
				'priority' => 200,
			)
		) );
 		/**
 		 * Body Style section
 		 */
 		$wp_customize->add_section( 'empowerment_typography_general_section',
 			array(
 				'title' => esc_html__( 'General', 'empowerment' ),
 				'panel' => 'empowerment_typography_panel',
 				'priority' => 5
 			)
 		);
 		/**
 		 * Body Style section
 		 */
 		$wp_customize->add_section( 'body_style',
 			array(
 				'title' => esc_html__( 'Body Style', 'empowerment' ),
 				'panel' => 'empowerment_typography_panel',
 				'priority' => 10
 			)
 		);
   		/**
 		 * Heading section
 		 */
   		$wp_customize->add_section( 'empowerment_heading_style',
   			array(
   				'title' => esc_html__( 'Heading Style', 'empowerment' ),
   				'panel' => 'empowerment_typography_panel',
   				'priority' => 20
   			)
		   );
   		/**
 		 * Font Awesome
 		 */
   		$wp_customize->add_section( 'empowerment_font_awesome_style',
   			array(
   				'title' => esc_html__( 'Font Awesome', 'empowerment' ),
   				'panel' => 'empowerment_typography_panel',
   				'priority' => 20
   			)
		   );
		/**
 		 * Heading section
 		 */
		  $wp_customize->add_section( 'empowerment_primary_menu_style',
		  array(
			  'title' => esc_html__( 'Primary Menu Style', 'empowerment' ),
			  'panel' => 'empowerment_header_panel',
			  'priority' => 20
		  )
	  );
 		/**
 		 * Header Layout Section
 		 */
 		$wp_customize->add_section('header_customizer_setting',
 			array(
 				'title' 	  => esc_html__('Header Layouts' , 'empowerment'),
 				'priority' => 10,
 				'panel'   => 'empowerment_header_panel'
 			)
 		);
 		/**
 		 * Header Style Section
 		 */
 		$wp_customize->add_section('empowerment_header_styles',
 			array(
 				'title' 	  => esc_html__('Header Styles' , 'empowerment'),
 				'priority' => 20,
 				'panel'   => 'empowerment_header_panel'
 			)
 		);
	    /**
	     * Breadcrumb Banner Section
	     */
	    $wp_customize->add_section('empowerment_breadcrumb_banner_section',
	    	array(
	    		'title'     => esc_html__('Banner Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_breadcrumb_panel',
	    		'priority' => 10
	    	)
	    );
	    /**
	     * Breadcrumb Settings Section
	     */
	    $wp_customize->add_section('empowerment_breadcrumb_section',
	    	array(
	    		'title'     => esc_html__('Breadcrumb Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_breadcrumb_panel',
	    		'priority' => 20
	    	)
	    );
	    /**
	     * Page Settings Section
	     */
	    $wp_customize->add_section('empowerment_page_setting_section',
	    	array(
	    		'title'     => esc_html__('Page Contents' , 'empowerment'),
	    		'panel'     => 'empowerment_page_panel',
	    		'priority' => 10
	    	)
	    ); 
	    /**
	     * Page Sidebar Settings Section
	     */
	    $wp_customize->add_section('empowerment_page_sidebar_section',
	    	array(
	    		'title'     => esc_html__('Sidebar Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_page_panel',
	    		'priority' => 20
	    	)
	    ); 
	    /**
	     * Blog Page Settings Section
	     */
	    $wp_customize->add_section('empowerment_blog_page_section',
	    	array(
	    		'title'     => esc_html__('Archive Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_archive_panel',
	    		'priority' => 10
	    	)
	    ); 
	    /**
	     * Blog Single Post Settings Section
	     */
	    $wp_customize->add_section('empowerment_single_post_section',
	    	array(
	    		'title'     => esc_html__('Single Post Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_archive_panel',
	    		'priority' => 20
	    	)
	    ); 
	    /**
	     * Archive Sidebar Settings Section
	     */
	    $wp_customize->add_section('empowerment_archive_sidebar_section',
	    	array(
	    		'title'     => esc_html__('Sidebar Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_archive_panel',
	    		'priority' => 30
	    	)
	    ); 
	    /**
	     * Meta Reorder Section
	     */
	    $wp_customize->add_section('empowerment_meta_setting_section',
	    	array(
	    		'title'     => esc_html__('Meta Settings' , 'empowerment'),
	    		'panel'     => 'empowerment_archive_panel',
	    		'priority' => 40
	    	)
	    ); 
	    /**
	     * Shop Settings Section
	     */
	    $wp_customize->add_section('empowerment_shop_setting_section',
	    	array(
	    		'title'     => esc_html__('Shop Page' , 'empowerment'),
	    		'panel'     => 'empowerment_shop_panel',
	    		'priority' => 10
	    	)
	    ); 
	    /**
	     * Related Product Section
	     */
	    $wp_customize->add_section('empowerment_shop_related_section',
	    	array(
	    		'title'     => esc_html__('Related Products' , 'empowerment'),
	    		'panel'     => 'empowerment_shop_panel',
	    		'priority' => 20
	    	)
	    ); 
	    /**
	     * Mini Cart Section
	     */
	    $wp_customize->add_section('empowerment_mini_cart_section',
	    	array(
	    		'title'     => esc_html__('Mini Cart' , 'empowerment'),
	    		'panel'     => 'empowerment_header_panel',
	    		'priority' => 30
	    	)
	    ); 
 		/**
 		 * Footer Layout Section
 		 */
 		$wp_customize->add_section('empowerment_footer_layout_section',
 			array(
 				'title' 	  => esc_html__('Footer Layouts' , 'empowerment'),
 				'panel' 	  => 'empowerment_footer_panel',
 				'priority' => 10
 			)
 		);
	    /**
	     * Footer Scroll Top Section
	     */
	    $wp_customize->add_section('empowerment_scroll_top_section',
	    	array(
	    		'title'     => esc_html__('Scroll Top' , 'empowerment'),
	    		'panel'     => 'empowerment_footer_panel',
	    		'priority' => 20
	    	)
	    );
 		/**
 		 * Theme color
 		 */
 		$wp_customize->add_section( 'empowerment_theme_color_section',
 			array(
 				'title' => esc_html__( 'Theme Color', 'empowerment' ),
 				'panel'  	  => 'empowerment_general_settings_panel'
 			)
		 );
		 /**
 		 * Additional settings
 		 */
		  $wp_customize->add_section( 'empowerment_additional_setting_section',
		  array(
			  'title' => esc_html__( 'Additional Settings', 'empowerment' ),
			  'panel'  	  => 'empowerment_general_settings_panel'
		  )
	  );

 		/**
 		 * Default Section Management
 		 */
 		$wp_customize ->get_section( 'title_tagline' )->panel = 'empowerment_general_settings_panel';
 		$wp_customize ->get_section( 'colors' )->panel = 'empowerment_general_settings_panel';
 		$wp_customize ->get_section( 'background_image' )->panel = 'empowerment_general_settings_panel';
 		$wp_customize ->get_section( 'static_front_page' )->priority = 40;
 		$wp_customize ->remove_section( 'header_image' );
 	}
 	/**
 	 * Register Header Controls
 	 */
 	public function empowerment_register_header_controls( $wp_customize ) {
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/header/header.php';
	 	require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/header/design.php';
 	}
 	/**
 	 * Register Typography Controls
 	 */
 	public function empowerment_register_typography_controls( $wp_customize ) {
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/typography/general.php';
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/typography/body.php';
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/typography/heading.php';
 	}
	/**
	* Register Breadcrumb Banner controls
	*/
	public function empowerment_register_bread_banner_controls( $wp_customize ) {
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/bread-banner/banner.php';
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/bread-banner/breadcrumb.php';
	}
	/**
	* Register Page controls
	*/
	public function empowerment_register_page_settings_controls( $wp_customize ) {
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/page/page.php';
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/page/sidebar.php';
	}
	/**
	* Register Archive controls
	*/
	public function empowerment_register_archive_settings_controls( $wp_customize ) {
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/archive/blog.php';
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/archive/single.php';
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/archive/sidebar.php';
		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/archive/meta.php';
	}
 	/**
 	 * Register footer controls
 	 */
 	public function empowerment_register_footer_settings_controls( $wp_customize ) {
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/footer/footer.php';
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/footer/scroll-top.php';
 	}
 	
 	/**
 	 * Register theme color
 	 */
 	public function empowerment_register_theme_color_controls( $wp_customize ){
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/theme-color/theme-color.php';
 	}
 	/**
 	* Register woocommerce control
 	*/
 	public function empowerment_woocommerce_controls($wp_customize){
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/woocommerce/shop.php';
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/woocommerce/related.php';
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/woocommerce/mini-cart.php';
 	}
 	/**
 	* Register Developer Mode Control
 	*/
 	public function empowerment_developer_controls($wp_customize){
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/dev/dev.php';
 	}
 	/**
 	* Register Seo setting Control
 	*/
 	public function empowerment_seo_controls($wp_customize){
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/seo/seo.php';
 	}
 	/**
 	* Register callback functions
 	*/
 	public function empowerment_registre_theme_active_callback() {
 		require_once trailingslashit( get_template_directory() ) . 'inc/empowerment-customizer/customizers/callback/active-callback.php';
 	}
 }   	
/**
* Load all our Customizer Custom Controls
*/
require_once trailingslashit( dirname(__FILE__) ) . 'custom-controls.php';
/**
* Initialise our Customizer settings
*/
$empowerment_settings = new Empowerment_Initialise_Customizer_Settings();